AndroidFlutterVision class

Inheritance
Implemented types

Constructors

AndroidFlutterVision()

Properties

channel MethodChannel
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

closeYoloModel() Future<void>
inherited
loadYoloModel({required String modelPath, required String labels, required String modelVersion, bool? quantization, int? numThreads, bool? useGpu, bool? isAsset, int? rotation}) Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
yoloOnFrame({required List<Uint8List> bytesList, required int imageHeight, required int imageWidth, double? iouThreshold, double? confThreshold, double? classThreshold}) Future<List<Map<String, dynamic>>>
override
yoloOnImage({required Uint8List bytesList, required int imageHeight, required int imageWidth, double? iouThreshold, double? confThreshold, double? classThreshold}) Future<List<Map<String, dynamic>>>
override

Operators

operator ==(Object other) bool
The equality operator.
inherited