Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
closeYoloModel()
→ Future<void>
-
dispose OCRModel, clean and save resources
-
loadYoloModel({required String modelPath, required String labels, required String modelVersion, bool? quantization, int? numThreads, bool? isAsset, bool? useGpu, int? rotation})
→ Future<void>
-
loadYoloModel: load YOLOv5 model from the assets folder
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
-
yoloOnFrame({required List<Uint8List> bytesList, required int imageHeight, required int imageWidth, double? iouThreshold, double? confThreshold, double? classThreshold})
→ Future<List<Map<String, dynamic>>>
-
yoloOnFrame accept a byte List as input and
return a List<Map<String, dynamic>>.
-
yoloOnImage({required Uint8List bytesList, required int imageHeight, required int imageWidth, double? iouThreshold, double? confThreshold, double? classThreshold})
→ Future<List<Map<String, dynamic>>>
-
yoloOnImage accept a Uint8List as input and
return a List<Map<String, dynamic>>.